@@ -39,14 +39,19 @@ def report_network_qos(nets_info, devs_info):
     for net, attrs in six.viewitems(nets_info):
         iface = attrs['iface']
         if iface in devs_info['bridges']:
-            host_ports = [port for port in attrs['ports'] if
-                          not port.startswith('vnet')]
+            host_ports = [
+                port for port in attrs['ports'] if not port.startswith('vnet')
+            ]
             if not host_ports:  # Port-less bridge
                 continue
             if len(host_ports) > 1:
-                logging.error('Multiple southbound ports per network detected,'
-                              ' ignoring this network for the QoS report '
-                              '(network: %s, ports: %s)', net, host_ports)
+                logging.error(
+                    'Multiple southbound ports per network detected,'
+                    ' ignoring this network for the QoS report '
+                    '(network: %s, ports: %s)',
+                    net,
+                    host_ports,
+                )
                 continue
             iface, = host_ports
         if iface in devs_info['vlans']:
@@ -55,18 +60,19 @@ def report_network_qos(nets_info, devs_info):
             iface_qdiscs = qdiscs.get(iface)
             if iface_qdiscs is None:
                 continue
-            class_id = (get_root_qdisc(iface_qdiscs)['handle'] + '%x' %
-                        vlan_id)
+            class_id = get_root_qdisc(iface_qdiscs)['handle'] + '%x' % vlan_id
         else:
             iface_qdiscs = qdiscs.get(iface)
             if iface_qdiscs is None:
                 continue
-            class_id = (get_root_qdisc(iface_qdiscs)['handle'] +
-                        DEFAULT_CLASSID)
+            class_id = get_root_qdisc(iface_qdiscs)['handle'] + DEFAULT_CLASSID
 
         # Now that iface is either a bond or a nic, let's get the QoS info
-        classes = [cls for cls in tc.classes(iface, classid=class_id) if
-                   cls['kind'] == 'hfsc']
+        classes = [
+            cls
+            for cls in tc.classes(iface, classid=class_id)
+            if cls['kind'] == 'hfsc'
+        ]
         if classes:
             cls, = classes
             attrs['hostQos'] = {'out': cls['hfsc']}
